<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="si">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>යෙදුම් ප්‍රොක්සිය</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>ප්‍රොක්සි වර්ගය</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP ලිපිනය</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>කෙවෙනිය</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>පරිශීලක නාමය</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>විකල්ප</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>මුර පදය</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>වින්‍යාස කිරීමෙන් පසු  වැඩසටහන් රඳවනයේ ඇති යෙදුම් සන්දර්භ මෙනුවේ &quot;ප්‍රොක්සියක් භාවිතා කරන්න&quot; සලකුණු කරන්න</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>අවලංගු කරන්න</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>සුරකින්න</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>වලංගු නොමැති IP ලිපිනයකි</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>වලංගු නොවන කෙවෙනියකි</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>විසන්ධි කරන්න</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>මකා දමන්න</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>අවලංගු කරන්න</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>සුරකින්න</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>විසන්ධි කරන්න</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>මෙම සැකසුම් මකා දැමීමට අවශ්‍ය බව ඔබට විශ්වාසද?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>රැහැන් සම්බන්ධතාවය: %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>හොට්ස්පොට්</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>රැහැන් රහිත සම්බන්ධතාවය: %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE සම්බන්ධතාවය %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>නව VPN සම්බන්ධතාවක්</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN වර්ගය</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>නිර්යාත කරන්න</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>ජාලය</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>යෙදුම් ප්‍රොක්සිය</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>පුද්ගලික හොට්ස්පොට්</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>ජාල විස්තර</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>පද්ධති ප්‍රොක්සිය</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>රැහැන්ගත ජාලය</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>රැහැන් රහිත ජාලය</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>රැහැන්ගත ජාල ඇඩැප්ටරය</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>ජාල සම්බන්ධතාවයක් එක් කරන්න</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>රැහැන් රහිත ජාල ඇඩැප්ටරය</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>සැඟවුණු ජාලයකට සම්බන්ධ වන්න</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE සම්බන්ධතාවයක් සාදන්න</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN තත්වය</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN සාදන්න</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN ආයාත කරන්න</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>ප්‍රොක්සි වර්ගය</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>වින්‍යාස URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP ලිපිනය</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>කෙවෙනිය</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>පරිශීලක නාමය</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>මුර පදය</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>හොට්ස්පොට්</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>හොට්ස්පොට් සාදන්න</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>අතුරුමුහුණත</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>කලාපය</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>දොරටුව-gateway</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>ප්‍රාථමික DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>නෙට්මාස්ක්</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>උපසර්ගය</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>වේගය</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>බැඳී නොමැත</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>උපාංගයේ MAC ලිපිනය</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>ක්ලෝන කළ MAC ලිපිනය</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU කැමති පරිදි සකසන්න</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>පොදු</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>නම</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>පොදු</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>නම දැනටමත් පවතී</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>නම</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>ස්වයංක්‍රීයව සම්බන්ධ වන්න</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>හොට්ස්පොට්</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>සැකසුම් එක් කරන්න</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>හොට්ස්පොට් සාදන්න</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP ලිපිනය</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>දොරටුව-gateway</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>වලංගු නොමැති IP ලිපිනයකි</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>වලංගු නොවන දොරටුවක්</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>නෙට්මාස්ක්</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>වලංගු නොමැති IP ලිපිනයකි</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>වලංගු නොවන දොරටුවක්</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>උපසර්ගය</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ස්වයංක්‍රීය</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>සව්‍යං</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>නොසලකා හරින්න</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP ලිපිනය</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>දොරටුව-gateway</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>අදාළ සම්පත් වල පමණක් යෙදී ඇත</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>ක්‍රමය</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>නෙට්මාස්ක්</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>උපසර්ගය</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>වලංගු නොමැති IP ලිපිනයකි</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>වලංගු නොවන දොරටුවක්</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>ජාලය</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>ක්‍රමය</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ස්වයංක්‍රීය</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>සව්‍යං</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>නොසලකා හරින්න</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>ජාල විස්තර</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>පද්ධති ප්‍රොක්සිය</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>යෙදුම් ප්‍රොක්සිය</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>ජාල විස්තර</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>ජාලය</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>අක්‍රීයයි</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>සව්‍යං</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ස්වයංක්‍රීය</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>ජාල කළමනාකරු විසින් වින්‍යාස කරන්න</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>පුද්ගලික හොට්ස්පොට්</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>පරිශීලක නාමය</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>සේවාව</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>මුර පදය</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP සත්‍යාපනය ප්‍රතික්ෂේප කරන්න</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP සත්‍යාපනය ප්‍රතික්ෂේප කරන්න</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP සත්‍යාපනය ප්‍රතික්ෂේප කරන්න</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP සත්‍යාපනය ප්‍රතික්ෂේප කරන්න</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 සත්‍යාපනය ප්‍රතික්ෂේප කරන්න</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD දත්ත සම්පීඩන කිරීමක් නොමැත</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Deflate දත්ත සම්පීඩන කිරීමක් නොමැත</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP ශීර්ෂ සම්පීඩනයක් නොමැත</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Protocol ක්ෂේත්‍ර සම්පීඩනය කිරීමක් නොමැත</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>ලිපිනය / පාලන සම්පීඩනය කිරීමක් නොමැත</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP Echo පැකට් යවන්න</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE භාවිතා කරන්න</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE සම්බන්ධතාවයක් සාදන්න</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>පද්ධති ප්‍රොක්සිය</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>අවලංගු කරන්න</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>සුරකින්න</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>ප්‍රොක්සි වර්ගය</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>සව්‍යං</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ස්වයංක්‍රීය</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>විකල්ප</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>කෙවෙනිය</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP ප්‍රොක්සි</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS ප්‍රොක්සි</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP ප්‍රොක්සි</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS ප්‍රොක්සි</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>ඉහත ධාරක-host සහ ඩොමේන් සඳහා ප්‍රොක්සි වින්‍යාසයන් නොසලකා හරින්න</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>වින්‍යාස URL</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>ආරක්ෂාව</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>උමං TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>ආරක්ෂිත EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>මෙම පරිශීලකයා සඳහා මුරපදය සුරකින්න</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>සියළු පරිශීලකයන් සඳහා මුරපදය සුරකින්න</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>සැමවිටම මගෙන් විමසන්න</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>අක්‍රීයයි</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>නිර්නාමික</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>සත්‍යාපනය කරන ලදි</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>දෙකම</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>ස්වයංක්‍රීය</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>අනුවාදය 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>අනුවාදය 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP සත්‍යාපනය</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>අනන්‍යතාවය</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>මුරපද විකල්ප</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>පුද්ගලික යතුරු කේතය</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA සහතිකය</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>පරිශීලක සහතිකය</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>නිර්නාමික හැඳුනුම් අංකය</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>ප්‍රතිපාදනය-Provisioning</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC ගොනුව</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>අභ්‍යන්තර සත්‍යාපනය</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP අනුවාදය</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>පුද්ගලික මුරපදය</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>මුර පදය</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>වලංගු නොවන මුරපදයකි</translation>
    </message>
    <message>
        <source>None</source>
        <translation>කිසිවක් නැත</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA / WPA2 පුද්ගලික</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>ආරක්ෂාව</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>යතුර</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>මුර පදය</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>ආරක්ෂාව අවශ්‍යයි</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>වලංගු නොවන මුරපදයකි</translation>
    </message>
    <message>
        <source>None</source>
        <translation>කිසිවක් නැත</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA / WPA2 පුද්ගලික</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation>හවුල් යතුර</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>පද්ධතිය විවෘත කරන්න</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>ආරක්ෂාව</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>සත්‍යාපනය</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>යතුර</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>මුර පදය</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>උසස් VPN </translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>දොරටු කෙවෙනිය කැමති පරිදි සකසන්න</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>දොරටු කෙවෙනිය</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>නැවත උත්සාහ කිරීමේ පරතරය කැමති පරිදි සකසන්න</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>නැවත උත්සාහ කිරීමේ අන්තරය</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>LZO දත්ත සම්පීඩනය භාවිතා කරන්න</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>TCP සම්බන්ධතාවය භාවිතා කරන්න</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>TAP උපාංගයක් භාවිතා කරන්න</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>උමං MTU කැමති පරිදි සකසන්න</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>UDP කොටස් පරිමාණය කැමති පරිදි සකසන්න</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP කොටස් පරිමාණය</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>උමං TCP MSS සීමා කරන්න</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>දුරස්ථ ධාරකයන් අහඹු ලෙස සකස් කරන්න</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>උසස් VPN </translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (පෙරනිමි)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>ආරක්ෂිත (පෙරනිමි)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>දුර්වලයි</translation>
    </message>
    <message>
        <source>None</source>
        <translation>කිසිවක් නැත</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>ලබා ගත හැකි විට NAT-T (පෙරනිමිය)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>සැමවිටම NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>අක්‍රීයයි</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH කාණ්ඩ 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH කාණ්ඩ 2 (සුපුරුදු)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH කාණ්ඩ 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>සේවාදායකය (සුපුරුදු)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH කාණ්ඩ 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>වසම</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>විකුණුම්කරු</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>අනුවාදය</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>සංකේතනය</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT සංචලන ප්‍රකාරය</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH කාණ්ඩය</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>රහස්‍යභාවය ඉදිරියට ගෙනයන්න</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>ස්ථානීය-local කෙවෙනිය</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>මල තුල්‍ය-Dead peer හඳුනාගැනීම අක්‍රීය කරන්න</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>IPsec සක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>කණ්ඩායම් නම</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>කණ්ඩායම් හැඳුනුම් අංකය/නම</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>පෙර-හවුල් යතුර</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>අදියර 1 ඇල්ගොරිතම</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>අදියර 2 ඇල්ගොරිතම</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>වලංගු නොවන දොරටුවක්</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>දොරටුව-gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA සහතිකය</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>ප්‍රොක්සි</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>ඩෙස්ක්ටොප් ට්‍රෝජන් වලින් ආරක්ෂා කිරීමට Cisco හට ඉඩදෙන්න</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD ස්ක්‍රිප්ට්</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>පරිශීලක සහතිකය</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>පුද්ගලික යතුරු කේතය</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>යතුරු මුරපදය සඳහා FSID භාවිතා කරන්න</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>වලංගු නොවන දොරටුවක්</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>සහතික (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>මුර පදය</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>මුරපදය සහිත සහතික (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>ස්ථිතික යතුර</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>සුරකින ලදි</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>අහන්න</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>අත්‍යවශ්‍යය නොවේ</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>දොරටුව-gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>සත්‍යාපන වර්ගය</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA සහතිකය</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>පරිශීලක සහතිකය</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>පුද්ගලික යතුරු කේතය</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>මුරපද විකල්ප</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>පුද්ගලික මුරපදය</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>පරිශීලක නාමය</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>යතුරු දිශාව කැමති පරිදි සකසන්න</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>යතුරු දිශාව</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>දුරස්ථ IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>ස්ථානික IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>පවතින සියල්ලම (පෙරනිමිය)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (අඩු ආරක්ෂිත)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (වඩාත්ම ආරක්ෂිත)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP සත්‍යාපනය ප්‍රතික්ෂේප කරන්න</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP සත්‍යාපනය ප්‍රතික්ෂේප කරන්න</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP සත්‍යාපනය ප්‍රතික්ෂේප කරන්න</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP සත්‍යාපනය ප්‍රතික්ෂේප කරන්න</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 සත්‍යාපනය ප්‍රතික්ෂේප කරන්න</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD දත්ත සම්පීඩන කිරීමක් නොමැත</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Deflate දත්ත සම්පීඩන කිරීමක් නොමැත</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP ශීර්ෂ සම්පීඩනයක් නොමැත</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Protocol ක්ෂේත්‍ර සම්පීඩනය කිරීමක් නොමැත</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>ලිපිනය / පාලන සම්පීඩනය කිරීමක් නොමැත</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP Echo පැකට් යවන්න</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE භාවිතා කරන්න</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>ආරක්ෂාව</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN තත්වය</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN සාදන්න</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN ආයාත කරන්න</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>ආයාත කිරීමේ දෝෂයකි</translation>
    </message>
    <message>
        <source>File error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>හරි</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN ප්‍රොක්සි</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>අත්‍යවශ්‍යය නොවේ</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>ප්‍රොක්සි වර්ගය</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>සේවාදායක IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>කෙවෙනිය</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>අසමත් වූ විට නැවත නැවත උත්සාහ කරන්න</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>පරිශීලක නාමය</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>මුර පදය</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA ගොනුව</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>සහතික අනතුරු ඇඟවීම් නොසලකා හරින්න</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>TLS ධාරක නාම දිගු භාවිතා කරන්න</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN ආරක්ෂාව</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>පෙරනිමිය</translation>
    </message>
    <message>
        <source>None</source>
        <translation>කිසිවක් නැත</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>කේතාංකය</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC සත්‍යාපනය</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>වලංගු නොවන දොරටුවක්</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>සුරකින ලදි</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>අහන්න</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>අත්‍යවශ්‍යය නොවේ</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>දොරටුව-gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>පරිශීලක නාමය</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>මුරපද විකල්ප</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>මුර පදය</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT වසම</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN ප්‍රොක්සි</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>සේවාදායක IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>කෙවෙනිය</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>පරිශීලක නාමය</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>මුර පදය</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>වලංගු නොවන දොරටුවක්</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>පුද්ගලික යතුරු කේතය</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH නියෝජිත</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>ස්මාට් කාඩ්</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>පෙර-හවුල් යතුර</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>දොරටුව-gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA සහතිකය</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>සත්‍යාපන වර්ගය</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>පරිශීලක සහතිකය</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>පරිශීලක නාමය</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>මුර පදය</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>අභ්‍යන්තර IP ලිපිනයක් ඉල්ලීම</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>UDP සංවෘත කිරීම බලාත්මක කරන්න</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>IP සම්පීඩනය භාවිතා කරන්න</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>අභිරුචි කේතාංක යෝජනා සක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS සත්‍යාපනය</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>පෙරනිමිය</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>සේවාදායකයා</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>සේවාදායකය</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>කාරණය ගැලපීම</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>දුරස්ථ සහතික වර්ගය</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>යතුරු කේතය</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>යතුරු දිශාව කැමති පරිදි සකසන්න</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>යතුරු දිශාව</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>වලංගු නොවන දොරටුවක්</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>සුරකින ලදි</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>අහන්න</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>අත්‍යවශ්‍යය නොවේ</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>දොරටුව-gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>පරිශීලක නාමය</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>මුරපද විකල්ප</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>මුර පදය</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>කණ්ඩායම් නම</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>කණ්ඩායම් මුරපදය</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>දෙමුහුන් සත්‍යාපනය භාවිතා කරන්න</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA ගොනුව</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>පළමුව ජාල කේබලය සම්බන්ධ කරන්න</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>රැහැන්ගත ජාල ඇඩැප්ටරය</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>ජාල සම්බන්ධතාවයක් එක් කරන්න</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>සැකසුම් තෝරන්න</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>රැහැන් රහිත ජාල ඇඩැප්ටරය</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>හොට්ස්පොට් වසන්න</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>ඔබට රැහැන් රහිත ජාලයකට සම්බන්ධ වීමට අවශ්‍ය නම් පළමුව හොට්ස්පොට් අක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>සැඟවුණු ජාලයකට සම්බන්ධ වන්න</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>බැඳී නොමැත</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>අත්‍යවශ්‍යයි</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>උපාංගයේ MAC ලිපිනය</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU කැමති පරිදි සකසන්න</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>හොට්ස්පොට්</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>ප්රොටෝකෝලය</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>ආරක්ෂක වර්ගය</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>නාලිකාව</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>කලාපය</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>අතුරුමුහුණත</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>නෙට්මාස්ක්</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>දොරටුව-gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>ප්‍රාථමික DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>උපසර්ගය</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>වේගය</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>උපාංගය අක්‍රීය කර ඇත</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>ජාලගතව ඇතත් අන්තර්ජාල ප්‍රවේශය නොමැත</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>සම්බන්ධතා නොමැත</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>ජාල කේබලය විසන්ධි කර ඇත</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>සම්බන්ධ වෙමින් පවතී</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>සත්‍යාපනය කිරීම</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP ලිපිනය ලබා ගැනීම</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>සම්බන්ධයි</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>විසන්ධි වි ඇත</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>අසමත් විය</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>රැහැන්ගත ජාලය</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>රැහැන්ගත ජාලය %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>රැහැන් රහිත ජාලය</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>රැහැන් රහිත ජාලය %1</translation>
    </message>
</context>
</TS>